@@ -26,12 +26,23 @@ DOT_ALDRYN_FILE_NOT_FOUND = (
 def get_project_settings(path=None, silent=False):
     project_home = get_application_home(path, silent=silent)
     try:
+        old_file_found = False
         if os.path.exists(
             os.path.join(project_home, settings.ALDRYN_DOT_FILE)
         ):
             path = os.path.join(project_home, settings.ALDRYN_DOT_FILE)
-        else:
+            old_file_found = True
+
+        if os.path.exists(os.path.join(project_home, settings.DIVIO_DOT_FILE)):
             path = os.path.join(project_home, settings.DIVIO_DOT_FILE)
+            if old_file_found:
+                click.secho(
+                    "Warning: Old ({}) and new ({}) divio configuration files found at the same time. The new one will be used.".format(
+                        settings.ALDRYN_DOT_FILE, settings.DIVIO_DOT_FILE
+                    ),
+                    fg="yellow",
+                )
+
         with open(path) as fh:
             return json.load(fh)
     except (TypeError, OSError):
@@ -89,7 +100,7 @@ def get_docker_compose_cmd(path):
         )
 
     conf = config.Config()
-    cmd = conf.config.get("docker-compose", ["docker-compose"])
+    cmd = conf.get_docker_compose_cmd()
     docker_compose_base = cmd + ["-f", docker_compose_filename]
 
     def docker_compose(*commands):
@@ -251,9 +262,14 @@ class DockerComposeConfig(object):
             return False
 
         for mount in service_config.get("volumes", []):
-            bits = mount.strip().split(":")
-            if len(bits) > 2 and bits[-2] == remote_path:
-                return True
+            # docker compose < 2
+            if not isinstance(mount, dict):
+                bits = mount.strip().split(":")
+                if len(bits) > 2 and bits[-2] == remote_path:
+                    return True
+            else:
+                if mount["target"] == remote_path:
+                    return True
 
 
 def allow_remote_id_override(func):
