@@ -15,10 +15,10 @@ TEST_COMMANDS_CLICK = [
     ["project", "deploy-log"],
     ["project", "env-vars"],
     ["project", "list"],
-    # ["project", "pull", "db"],
-    # ("project", "push", "db", "--noinput"),
+    ["project", "pull", "db"],
+    ["project", "push", "db", "--noinput"],
     ["project", "export", "db"],
-    # ("project", "push", "db", "--noinput", "--dumpfile", "local_db.sql"),
+    ["project", "push", "db", "--noinput", "--dumpfile", "local_db.sql"],
     ["project", "pull", "media"],
     ["project", "push", "media", "--noinput"],
     ["project", "logs", "test"],
@@ -35,4 +35,5 @@ TEST_COMMANDS_CLICK = [
 def test_call_click_commands(divio_project, command):
     runner = CliRunner()
     result = runner.invoke(cli.cli, command)
+    print(result.output)
     assert result.exit_code == 0
